let ctx = null;
const updateCounters = /* @__PURE__ */ new WeakMap();
const elements = /* @__PURE__ */ new Set();
function initCanvas() {
  const canvas = document.createElement("canvas");
  canvas.id = "vue-change-marker-canvas";
  canvas.style.position = "fixed";
  canvas.style.top = "0";
  canvas.style.left = "0";
  canvas.style.width = "100vw";
  canvas.style.height = "100vh";
  canvas.style.pointerEvents = "none";
  canvas.style.zIndex = "2147483646";
  canvas.setAttribute("aria-hidden", "true");
  const canvasCtx = canvas.getContext("2d");
  ctx = canvasCtx;
  document.documentElement.appendChild(canvas);
  const dpi = window.devicePixelRatio || 1;
  canvasCtx.canvas.width = dpi * window.innerWidth;
  canvasCtx.canvas.height = dpi * window.innerHeight;
  canvas.style.width = `${window.innerWidth}px`;
  canvas.style.height = `${window.innerHeight}px`;
  canvasCtx.resetTransform();
  canvasCtx.scale(dpi, dpi);
}
function clearCanvas(ctx2) {
  ctx2.save();
  ctx2.setTransform(1, 0, 0, 1, 0, 0);
  const width = ctx2.canvas.width;
  const height = ctx2.canvas.height;
  ctx2.clearRect(0, 0, width, height);
  ctx2.restore();
}
function resetCounters() {
  elements.forEach((el) => {
    updateCounters.set(el, 0);
  });
}
function highlight(ctx2, el, updatedInstance) {
  let updateCounter = updateCounters.get(el) || 0;
  updateCounter++;
  updateCounters.set(el, updateCounter);
  elements.add(el);
  const padding = 4;
  const opacity = Math.min(0.8, updateCounter * 0.3);
  const rect = el.getBoundingClientRect();
  const componentName = updatedInstance.type.name || updatedInstance.type.__name || updatedInstance.type.__file || "Anonymous";
  ctx2.save();
  if (rect.width >= 120) {
    ctx2.font = "14px Arial";
    const componentText = `<${componentName}/>`;
    const timesText = `updated times: ${updateCounter}`;
    const textWidth = Math.max(
      ctx2.measureText(componentText).width,
      ctx2.measureText(timesText).width
    );
    ctx2.fillStyle = `rgba(74, 222, 128, ${opacity})`;
    if (rect.y > 40) {
      ctx2.fillRect(rect.x, rect.y - 40, textWidth + padding * 2, 40);
    } else {
      ctx2.fillRect(rect.x, rect.y, textWidth + padding * 2, 40);
    }
    ctx2.fillStyle = `white`;
    if (rect.y > 40) {
      ctx2.fillText(componentText, rect.x + padding, rect.y - 25);
      ctx2.fillText(timesText, rect.x + padding, rect.y - 5);
    } else {
      ctx2.fillText(componentText, rect.x + padding, rect.y - 25 + 40);
      ctx2.fillText(timesText, rect.x + padding, rect.y - 5 + 40);
    }
  } else {
    ctx2.font = "14px Arial";
    const timesTextWidth = ctx2.measureText(`${updateCounter}`).width;
    ctx2.fillStyle = `rgba(74, 222, 128, ${opacity})`;
    ctx2.fillRect(rect.x, rect.y - 20, timesTextWidth + padding * 2, 20);
    ctx2.fillStyle = `white`;
    ctx2.fillText(`${updateCounter}`, rect.x + padding, rect.y - padding);
  }
  ctx2.restore();
  ctx2.save();
  ctx2.strokeStyle = `rgba(74, 222, 128, ${opacity})`;
  ctx2.lineWidth = 1;
  ctx2.strokeRect(rect.x, rect.y, rect.width, rect.height);
  ctx2.restore();
}
export {
  clearCanvas,
  ctx,
  highlight,
  initCanvas,
  resetCounters
};
